@@ -2,7 +2,7 @@ from typing import Optional
 from collections.abc import MutableMapping
 import os
 import configparser
-import appdirs
+import platformdirs
 
 from ofxstatement.exceptions import Abort
 
@@ -11,11 +11,11 @@ APP_AUTHOR = "ofx"
 
 
 def get_default_location() -> str:
-    cdir = appdirs.user_config_dir(APP_NAME, APP_AUTHOR)
+    cdir = platformdirs.user_config_dir(APP_NAME, APP_AUTHOR)
     return os.path.join(cdir, "config.ini")
 
 
-def read(location: str = None) -> Optional[MutableMapping]:
+def read(location: Optional[str] = None) -> Optional[MutableMapping]:
     if not location:
         location = get_default_location()
 
