@@ -126,13 +126,13 @@ class OfxWriter(object):
         self.buildAmount("TRNAMT", line.amount)
         self.buildText("FITID", line.id)
         self.buildText("CHECKNUM", line.check_no)
-        self.buildText("NAME", line.payee)
-        self.buildText("MEMO", line.memo)
         self.buildText("REFNUM", line.refnum)
+        self.buildText("NAME", line.payee)
         if line.bank_account_to:
             tb.start("BANKACCTTO", {})
             self.buildBankAccount(line.bank_account_to)
             tb.end("BANKACCTTO")
+        self.buildText("MEMO", line.memo)
         if line.currency is not None:
             self.buildCurrency("CURRENCY", line.currency)
         if line.orig_currency is not None:
@@ -150,12 +150,14 @@ class OfxWriter(object):
         tb = self.tb
         tb.start("SECLISTMSGSRSV1", {})
         tb.start("SECLIST", {})
-        tb.start("STOCKINFO", {})
 
         # get unqiue tickers
         for security_id in dict.fromkeys(
             map(lambda x: x.security_id, self.statement.invest_lines)
         ):
+            if security_id is None:
+                continue
+            tb.start("STOCKINFO", {})
             tb.start("SECINFO", {})
             tb.start("SECID", {})
             self.buildText("UNIQUEID", security_id)
@@ -164,8 +166,8 @@ class OfxWriter(object):
             self.buildText("SECNAME", security_id)
             self.buildText("TICKER", security_id)
             tb.end("SECINFO")
+            tb.end("STOCKINFO")
 
-        tb.end("STOCKINFO")
         tb.end("SECLIST")
         tb.end("SECLISTMSGSRSV1")
 
@@ -199,12 +201,21 @@ class OfxWriter(object):
         tb.end("INVSTMTMSGSRSV1")
 
     def buildInvestTransaction(self, line: InvestStatementLine) -> None:
-        # invest transactions must always have trntype and trntype_detailed
-        if line.trntype is None or line.trntype_detailed is None:
+        # invest transactions must always have trntype
+        if line.trntype is None:
             return
 
         tb = self.tb
 
+        if line.trntype == "INVBANKTRAN":
+            tb.start(line.trntype, {})
+            bankTran = StatementLine(line.id, line.date, line.memo, line.amount)
+            bankTran.trntype = line.trntype_detailed
+            self.buildBankTransaction(bankTran)
+            self.buildText("SUBACCTFUND", "OTHER")
+            tb.end(line.trntype)
+            return
+
         tran_type_detailed_tag_name = None
         inner_tran_type_tag_name = None
         if line.trntype.startswith("BUY"):
@@ -213,6 +224,10 @@ class OfxWriter(object):
         elif line.trntype.startswith("SELL"):
             tran_type_detailed_tag_name = "SELLTYPE"
             inner_tran_type_tag_name = "INVSELL"
+        elif line.trntype == "TRANSFER":
+            # Transfer transactions don't have details or an envelope
+            tran_type_detailed_tag_name = None
+            inner_tran_type_tag_name = None
         else:
             tran_type_detailed_tag_name = "INCOMETYPE"
             inner_tran_type_tag_name = (
@@ -220,7 +235,8 @@ class OfxWriter(object):
             )
 
         tb.start(line.trntype, {})
-        self.buildText(tran_type_detailed_tag_name, line.trntype_detailed, False)
+        if tran_type_detailed_tag_name:
+            self.buildText(tran_type_detailed_tag_name, line.trntype_detailed, False)
 
         if inner_tran_type_tag_name:
             tb.start(inner_tran_type_tag_name, {})
@@ -260,15 +276,14 @@ class OfxWriter(object):
             line.unit_price,
             precision=self.invest_transactions_float_precision,
         )
-        self.buildAmount("UNITS", line.units)
-
         self.buildAmount(
-            "TOTAL",
-            line.amount,
-            False,
+            "UNITS",
+            line.units,
             precision=self.invest_transactions_float_precision,
         )
 
+        self.buildAmount("TOTAL", line.amount)
+
         if inner_tran_type_tag_name:
             tb.end(inner_tran_type_tag_name)
         tb.end(line.trntype)
