@@ -1,6 +1,12 @@
 import unittest
+from unittest import mock
 
-import mock
+import sys
+
+if sys.version_info < (3, 10):
+    from importlib_metadata import EntryPoints
+else:
+    from importlib.metadata import EntryPoints
 
 from ofxstatement import plugin
 
@@ -13,9 +19,9 @@ class PluginTest(unittest.TestCase):
 
         ep = mock.Mock()
         ep.load.return_value = SamplePlugin
-
-        ep_patch = mock.patch("pkg_resources.iter_entry_points", return_value=[ep])
-
+        ep_patch = mock.patch(
+            "ofxstatement.plugin.entry_points", return_value=EntryPoints([ep])
+        )
         with ep_patch:
             p = plugin.get_plugin("sample", mock.Mock("UI"), mock.Mock("Settings"))
             self.assertIsInstance(p, SamplePlugin)
@@ -23,7 +29,9 @@ class PluginTest(unittest.TestCase):
     def test_get_plugin_conflict(self) -> None:
         ep = mock.Mock()
 
-        ep_patch = mock.patch("pkg_resources.iter_entry_points", return_value=[ep, ep])
+        ep_patch = mock.patch(
+            "ofxstatement.plugin.entry_points", return_value=EntryPoints([ep, ep])
+        )
         with ep_patch:
             with self.assertRaises(plugin.PluginNameConflict):
                 plugin.get_plugin("conflicting", mock.Mock("UI"), mock.Mock("Settings"))
