@@ -7,8 +7,7 @@ import logging
 import logging.handlers
 import shutil
 from typing import Dict
-
-import mock
+from unittest import mock
 
 from ofxstatement import tool, statement, configuration, parser, exceptions
 
@@ -39,7 +38,7 @@ class ToolTests(unittest.TestCase):
         self.assertEqual(ret, 0)
         self.assertEqual(
             self.log.getvalue().splitlines(),
-            ["INFO: Conversion completed: %s" % inputfname],
+            ["INFO: Conversion completed: (0 lines) %s" % inputfname],
         )
 
     def test_convert_noconf(self) -> None:
@@ -65,7 +64,7 @@ class ToolTests(unittest.TestCase):
 
         self.assertEqual(
             self.log.getvalue().splitlines(),
-            ["INFO: Conversion completed: %s" % inputfname],
+            ["INFO: Conversion completed: (0 lines) %s" % inputfname],
         )
 
     def test_convert_parseerror(self) -> None:
