@@ -1,5 +1,6 @@
 """Command line tool for converting statements to OFX format
 """
+
 import os
 import argparse
 import shlex
@@ -9,17 +10,26 @@ import platform
 import sys
 import contextlib
 
-import pkg_resources
+if sys.version_info < (3, 10):
+    from importlib_metadata import version
+else:
+    from importlib.metadata import version
+
 
 from ofxstatement import ui, configuration, plugin, ofx, exceptions
+from typing import Optional, TextIO, Generator
 
 
 log = logging.getLogger(__name__)
 
 
 @contextlib.contextmanager
-def smart_open(filename: str = None, encoding: str = None):
+def smart_open(
+    filename: Optional[str] = None, encoding: Optional[str] = None
+) -> Generator[TextIO, None, None]:
     """See https://stackoverflow.com/questions/17602878/how-to-handle-both-with-open-and-sys-stdout-nicely"""  # noqa
+    fh: TextIO
+
     if filename and filename != "-":
         # encoding is required in cases when OS defaults to encoding which
         # doesn't support unicode characters, for example Windows defaults to
@@ -36,8 +46,7 @@ def smart_open(filename: str = None, encoding: str = None):
 
 
 def get_version() -> str:
-    dist = pkg_resources.get_distribution("ofxstatement")
-    return dist.version
+    return version("ofxstatement")
 
 
 def configure_logging(args: argparse.Namespace) -> None:
@@ -69,6 +78,13 @@ def make_args_parser() -> argparse.ArgumentParser:
     # convert
     parser_convert = subparsers.add_parser("convert", help="convert to OFX")
 
+    parser_convert.add_argument(
+        "-c",
+        "--config",
+        metavar="myconfig.ini",
+        default=None,
+        help="custom config file to use",
+    )
     parser_convert.add_argument(
         "-t",
         "--type",
@@ -140,7 +156,7 @@ def edit_config(args: argparse.Namespace) -> None:
 
 def convert(args: argparse.Namespace) -> int:
     appui = ui.UI()
-    config = configuration.read()
+    config = configuration.read(args.config)
 
     if config is None:
         # No configuration mode
@@ -189,7 +205,11 @@ def convert(args: argparse.Namespace) -> int:
         writer = ofx.OfxWriter(statement)
         out.write(writer.toxml(pretty=args.pretty))
 
-    log.info("Conversion completed: %s" % args.input)
+    n_lines = len(statement.lines)
+    log.info(
+        "Conversion completed: (%d line%s) %s"
+        % (n_lines, "s" if n_lines != 1 else "", args.input)
+    )
     return 0  # success
 
 
